@@ -119,7 +119,7 @@ SilentProfile=False
 DimmDisplay=False
 PreviousBrightness=5
 RecordingBrightness=0
-PreviousProfile="silent"
+Previous_Profile_was_silent=False
 PreviousVolume=50
 
 gstream_player=""
@@ -143,7 +143,7 @@ StopAfterAlarm=True
 Status=""
 Progress=""
 
-#arrays, indexes, lenghts
+#arrays, indexes, lengths
 #             [0]=time            [1]=X, [2]=Y, [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
 arrDataTemp=[0, 0, 0] #[0]=X, [1]=Y, [2]=Z
 arrDataIndex=0
@@ -199,7 +199,13 @@ AlternativeAlarm=""
 cliStart=""
 cliStop=""
 
-CurrentVolume=5 #start value for wake up music
+CurrentVolume=0 #start value for wake up music
 WakeUp_Song_Volume_Increase_Step=4 #increase step time in pro mille (0.1%)
+WakeUp_Song_Start_Volume=10
 
 SongIsPlaying=False
+Timer_MusicPlayer=0
+
+glib_loop=""
+
+Error_Huck_installed=False
