@@ -26,6 +26,7 @@ import records #record data
 from functions_general import *
 from functions_record import *
 
+
 try:
     import alarm #maemo specific
 except:
@@ -36,6 +37,32 @@ _ = i18n.language.ugettext
 
 
 
+
+
+
+
+###########################################################################
+## Function:    CalculateAlarmtime
+## Description: Takes the choosen alarm hour and minute and generates the resulting timestamp
+## Parameters:  none
+## Returns:     none
+###########################################################################
+def CalculateAlarmtime(h, m):
+    hour_and_minute_now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #hour and minute now in sec
+    hour_and_minute_alarm=int(h)*3600+int(m)*60 #hour and minute of alarm in sec
+    alarmdiff=hour_and_minute_alarm-hour_and_minute_now
+    if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
+        alarmdiff=alarmdiff+86400
+    alarm=Tuple2Seconds(time.localtime())+alarmdiff
+    alarm=int((alarm)/60)*60 #set seconds to zero
+#    print alarm
+    return alarm
+
+
+
+
+
+
 ###########################################################################
 ## Function:    SetAlarm
 ## Description: This function adds the alarm to the MAEMO alarm queue
@@ -206,9 +233,10 @@ def DeleteAlarm():
 ##                alarm curve is over the trigger level and sets off an alarm
 ##                or the wake up music
 ## Parameters:  none
-## Returns:     none
+## Returns:     0: no action needed, 1: start Wake Up Music, 2: Stop wakeUp Music
 ###########################################################################
 def ProcessAlarm():
+    r=0
     i=records.Index-data.Derivation
     if(i>1): peak=records.arrData[6][i-1] #New: use blue graph for triggering
     else: peak=0
@@ -223,6 +251,9 @@ def ProcessAlarm():
                     records.AlarmTime_tuple=time.localtime()#set to now
                     records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple)
 
+
+                    print "Use_WakeUp_Song:", records.Use_WakeUp_Song
+
                     if(records.Use_WakeUp_Song==True): #Delay alarm, so we can first play wake up song
                         print "* Alarm would be now:", records.AlarmTime_tuple
                         print "* But wake Up song is enabled, delay alarm for", records.WakeUp_Song_Duration/60, "minutes"
@@ -233,7 +264,11 @@ def ProcessAlarm():
                         print "* Delay alarm until:", records.AlarmTime_tuple
 
                         print "** Play wake up song"
-                        PlaySong(0, records.WakeUp_Song) #start quiet, get louder over time
+#                        PlaySong(0, records.WakeUp_Song) #start quiet, get louder over time
+#                        MusicPlayer_Stop() #close media player in case still in use from the lucid dream option
+                        data.CurrentVolume=data.WakeUp_Song_Start_Volume
+#                        MusicPlayer_Play(data.WakeUp_Song_Start_Volume, records.WakeUp_Song, records.WakeUp_Song_Duration) #start quiet, get louder over time
+                        r=1
 
                     print "*", strftime("%x %X"), "ProcessAlarm => SetAlarm" #for log file
                     SetAlarm() #set alarm to go off now (or with wake up song delay)
@@ -243,7 +278,8 @@ def ProcessAlarm():
                     data.AlarmIsActive=True
                     data.Lucid_Dream_SongIsActive=True #make sure lucid dream option will not run after wake up option got active
 #                    PauseSong() #stop playing song, in case it was playing
-                    StopMediaPlayer() #close media player
+#                    MusicPlayer_Stop() #close media player
+                    r=2
 
     elif(now>=records.AlarmTimeWindowEnd_seconds): #End of alarm time window, set alarm off anyway
         if(records.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
@@ -252,22 +288,27 @@ def ProcessAlarm():
             data.AlarmIsActive=True
             data.Lucid_Dream_SongIsActive=True #make sure lucid dream option will not run after wake up option got active
 #            PauseSong() #stop playing song, in case it was playing
-            StopMediaPlayer() #close media player
+#            MusicPlayer_Stop() #close media player
+            r=2
 
     elif(records.Use_WakeUp_Song==True and (now+records.WakeUp_Song_Duration>=records.AlarmTimeWindowEnd_seconds)): #almost at end of alarm time window, play wake up song
         if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not yet playing
             data.WakeUp_SongIsActive=True
             records.WakeUp_Song_Start_tuple=Seconds2Tuple(now)
             print "** Play wake up song"
-            PlaySong(0, records.WakeUp_Song) #start quiet, get louder over time
+#            MusicPlayer_Stop() #close media player in case still in use from the lucid dream option
+            data.CurrentVolume=data.WakeUp_Song_Start_Volume
+#            MusicPlayer_Play(data.WakeUp_Song_Start_Volume, records.WakeUp_Song, records.WakeUp_Song_Duration) #start quiet, get louder over time
+            r=1
 
-    if(data.WakeUp_SongIsActive==True): #when WakeUp music is active, increase volume over time
+    if(data.WakeUp_SongIsActive==True and data.SongIsPlaying==True): #when WakeUp music is active, increase volume over time
 #        print records.WakeUp_Song_Volume,  data.CurrentVolume, data.CurrentVolume, float(data.WakeUp_Song_Volume_Increase_Step)/10, data.WakeUp_Song_Volume_Increase_Step
         if(records.WakeUp_Song_Volume>=data.CurrentVolume):
             data.CurrentVolume=data.CurrentVolume+(float(data.WakeUp_Song_Volume_Increase_Step)/10) #increase the volume slowly
             SetVolume(data.CurrentVolume)
             print "Increase volume to:", data.CurrentVolume
 
+    return r
 
 
 
@@ -277,13 +318,17 @@ def ProcessAlarm():
 ## Description: This function sets off the lucid dream music if we are
 ##                longer than required time in light or deep sleep
 ## Parameters:  none
-## Returns:     none
+## Returns:     0: no action needed , 1: Start Lucid dream music
 ###########################################################################
-def ProcessLucid_Dream(): #Lucid dream option
+def ProcessLucid_Dream(self): #Lucid dream option
     if(records.Use_Lucid_Dream_Song==True and data.Lucid_Dream_SongIsActive==False):
         GenerateStatisticData()
         if(records.arrStatData[1][2] >= records.Lucid_Dream_Song_Delay or records.arrStatData[2][2] >= records.Lucid_Dream_Song_Delay):
             data.Lucid_Dream_SongIsActive=True
             records.Lucid_Dream_Song_Start_tuple=time.localtime() #now
             print "Play Lucid dream song"
-            PlaySong(records.Lucid_Dream_Song_Volume, records.Lucid_Dream_Song)
+#            PlaySong(records.Lucid_Dream_Song_Volume, records.Lucid_Dream_Song)
+#            duration=GetSongLength(records.Lucid_Dream_Song)
+#            MusicPlayer_Play(records.Lucid_Dream_Song_Volume, records.Lucid_Dream_Song, duration)
+            return 1 #start lucid dream music
+    return 0
