@@ -199,7 +199,10 @@ def StopRecordFile():
 ## Returns:     none
 ###########################################################################
 def LoadFileList():
-    print "Load list of all csv files in folder:", data.RecordFolder
+    try:
+        print "Load list of all csv files in folder:", data.RecordFolder
+    except:
+        pass
     data.arrRecordFiles=getFileList(data.RecordFolder,  "*.csv")
     if(data.debug==True): print data.arrRecordFiles
     if(data.RecordFilename>""):
