@@ -26,12 +26,15 @@ from dbus.mainloop.qt import DBusQtMainLoop
 
 #import shlex, subprocess
 
+
+#import gobject
+#gobject.threads_init()
+#
 #import pygst
 #pygst.require("0.10")
-##import gobject
-##gobject.threads_init()
 #import gst
 
+
 import data
 import filter_data #filter
 import records #record data
@@ -72,8 +75,6 @@ def LoadPresetNames():
             data.preset_names[i]=str(_("Preset")+" "+str(i+1))
             PresetNames.set('main', 'preset'+str(i+1), data.preset_names[i])
 
-  #  print data.preset_names
-
 
 
 
@@ -373,56 +374,6 @@ def Index2Tuple(Index):
 
 
 
-
-
-
-
-###########################################################################
-## Function:    SwitchModes
-## Description: This function switches to offline mode and silence profile
-##                if requested and restores the previos state after the recording
-## Parameters:  start: True (recording start), False (recording end)
-## Returns:     none
-###########################################################################
-def SwitchModes(start):
-    if(data.DeviceIsN900==True): #We are on a N900
-        if(data.QuickMode==False):  #only do in normal recording mode
-            if(start==True): #start of recording
-                if(data.SwitchedModes==False): #protection so it only gets switched once
-                    data.SwitchedModes=True
-                    if(data.OfflineMode==True): #change to offline mode
-                        set_profile(False)
-                    if(data.SilentProfile==True): #change to silent profile
-                        set_silent(True)
-                    data.PreviousVolume=GetVolume()
-
-                    if(data.DimmDisplay==True): #dimm display brightness
-                        SetBrightness(data.RecordingBrightness)
-
-                    if(data.cliStart!=""):
-                        cmd=data.cliStart+" &" #Expert option to run a script at recording start
-                        print "### Run command: ", cmd
-                        b = os.popen(cmd)
-                        b.close()
-
-            else: #end of recording
-                if(data.SwitchedModes==True): #protection so it only gets switched once
-                    data.SwitchedModes=False
-                    if(data.OfflineMode==True): #change to online mode
-                       set_profile(True)
-                    if(data.SilentProfile==True): #change to general profile
-                        set_silent(False)
-                    SetVolume(data.PreviousVolume)
-
-                    if(data.cliStop!=""):
-                        cmd=data.cliStop+" &" #Expert option to run a script at recording stop
-                        print "### Run command: ", cmd
-                        b = os.popen(cmd)
-                        b.close()
-
-
-
-
 ###########################################################################
 ## Function:    set_profile
 ## Description: This function switches to the requested online/offline mode
@@ -433,7 +384,7 @@ def set_profile(online):
     if(online==True):
         try:
             if(data.PreviousMode=="normal"): #was online mode (before start measurement), so restore
-                print "Change to online mode"
+                print "# Change to online mode"
                 cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
                 os.popen(cmd)
         except:
@@ -441,13 +392,12 @@ def set_profile(online):
     else: #offline
         try:
             cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
-            ret=os.popen2(cmd) #get current mode
-            p=ret[1].readline() #not used
-            p=ret[1].readline()
-            tmp=string.split(p, "\"")
+            ret=os.popen(cmd).read() #get current mode
+            tmp=string.split(ret, "\"")
             data.PreviousMode=tmp[1]
+            print "Mode:", data.PreviousMode
             if(data.PreviousMode=="normal"): #was normal, change to offline
-                print "Change to offline mode"
+                print "# Change to offline mode"
                 cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
                 os.popen(cmd)
         except:
@@ -457,6 +407,28 @@ def set_profile(online):
 
 
 
+###########################################################################
+## Function:    get_silent
+## Description: This function returs the current profile (general/silent)
+## Parameters: none
+## Returns:     True (Silent), False (General)
+###########################################################################
+def get_Silent():
+    if(data.DeviceIsN900==True):
+        try:
+            cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
+            ret=os.popen(cmd).read() #get current profile
+            tmp=string.split(ret, "\"")
+            print "Profile:", tmp[1]
+            if(tmp[1]=="silent"): return True
+            else: return False
+        except:
+            return False
+    else: return False
+
+
+
+
 
 
 ###########################################################################
@@ -465,30 +437,23 @@ def set_profile(online):
 ## Parameters:  silent: True (switch to silent profile), False (switch to normal profile)
 ## Returns:     none
 ###########################################################################
-def set_silent(silent):
-    if(silent==True):
+def set_silent(set_silent):
+    if(set_silent==True):
         try:
-            cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
-            ret=os.popen2(cmd) #get current profile
-            p=ret[1].readline() #not used
-            p=ret[1].readline()
-            tmp=string.split(p, "\"")
-            data.PreviousProfile=tmp[1]
-            if(data.PreviousProfile=="general"): #was general profile, change to silent profile
+            if(get_Silent()==False): #was general profile, change to silent profile
                 cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
                 os.popen(cmd)
-                print "Silent Profile activated"
+                print "# Silent Profile activated"
                 Notify(_("Silent Profile activated"))
         except:
             pass
     else: #normal
         try:
-            if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
+            if(get_Silent()==True): #was silent (before start measurement), so restore to general
                 cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
                 os.popen(cmd)  #set profile
-                print "General Profile activated"
+                print "# General Profile activated"
                 Notify(_("General Profile activated"))
-                os.popen(cmd)  #notification
         except:
             pass
 
@@ -505,7 +470,6 @@ def SetVolume(percent):
     p=int(percent)
     cmd="dbus-send --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.set_extension_property string:volume variant:uint32:"+str(p)
     os.popen(cmd)
-#    data.CurrentVolume=percent
 
 
 
@@ -558,7 +522,7 @@ def GetBrightness():
 ###########################################################################
 def SetBrightness(b):
     if(data.DeviceIsN900==True): #we are on a N900
-        print "Set brightness level :", b
+        print "# Set brightness level :", b
  #       cmd="echo "+ str(b)+" > /sys/class/backlight/acx565akm/brightness"
         cmd ="gconftool -s /system/osso/dsm/display/display_brightness -t int "+str(b)
         b = os.popen(cmd)
@@ -600,71 +564,6 @@ def getFileList(path,  filter):
 
 
 
-###########################################################################
-## Function:    PlaySong
-## Description: Sets the requested volume and opens the media player with the requested song
-## Parameters:  volume percent (0..100), path to song file
-## Returns:     none
-###########################################################################
-def PlaySong(volume, filename):
-    data.SongIsPlaying=True
-    print strftime("%x %X"), "Play", filename, "with volume", volume
-    cmd="dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:\"file:///"+str(filename)+"\""
-#    cmd="mplayer \""+str(filename)+"\""
-    SetVolume(volume)
-    b = os.popen(cmd)
-    b.close()
-#    proc = subprocess.Popen(cmd, shell=True)
-
-#    data.gstream_player = gst.element_factory_make("playbin2", "player")
-#    fakesink = gst.element_factory_make("fakesink", "fakesink")
-#    data.gstream_player.set_property("video-sink", fakesink)
-#
-#    data.gstream_player.set_property("uri", "file://" + filename)
-#    data.gstream_player.set_state(gst.STATE_PLAYING)
-
-
-
-
-
-
-
-
-###########################################################################
-## Function:    PauseSong
-## Description: This function switches the media player to pause
-## Parameters:  none
-## Returns:     volume percent: 0..100
-###########################################################################
-#def PauseSong():
-#    print strftime("%x %X"), "Pause song (if active)"
-#    cmd="dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.pause"
-#    b = os.popen(cmd)
-#    b.close()
-
-
-
-
-
-###########################################################################
-## Function:    StopMediaPlayer
-## Description: This function closes the media player
-## Parameters:  none
-## Returns:     none
-###########################################################################
-def StopMediaPlayer():
-    if(data.SongIsPlaying==True):
-        data.SongIsPlaying=False
-        print strftime("%x %X"), "Stop mediaplayer"
-        cmd="killall mediaplayer"
-#        cmd="killall mplayer"
-        b = os.popen(cmd)
-        b.close()
-#        data.gstream_player.set_state(gst.STATE_NULL)
-
-
-
-
 ###########################################################################
 ## Function:    GetSongLength
 ## Description: This function returns the duration of a song
@@ -685,24 +584,3 @@ def GetSongLength(filename):
         print "ERROR: Could not get song length!"
         print "Set to default 5 minutes"
     return duration
-
-
-
-
-###########################################################################
-## Function:    StopMediaPlayer
-## Description: This function can measure the time needed for a certain code block
-##                It is only used for debugging
-## Parameters:  text to be printer, reset time: True/False
-## Returns:     none
-############################################################################
-#def Show_passed_time(text="", reset=False):
-#    if(data.debug==False): return
-#    now=time.time()
-#    if(reset==True): data.passed_time=now
-#
-#    t=1000*(now-data.passed_time)
-#    t2=1000*(now-data.passed_time2)
-#    print "### ", str(int(t)), "ms, (", str(int(t2)), "ms delta): ", text
-#
-#    data.passed_time2 = time.time()
